@@ -16,14 +16,13 @@ pub async fn search(query: &str) -> Result<Vec<Addon>, Box<dyn std::error::Error
     Ok(addons)
 }
 
-pub async fn get_fileinfo(
-    addonId: usize,
-    fileId: usize,
-) -> Result<AddonFileDetail, Box<dyn std::error::Error>> {
-    let url = format!("{}/addon/{}/file/{}", BASE_URL, addonId, fileId);
+pub async fn get_files(
+    addon_id: usize,
+) -> Result<Vec<AddonFileDetail>, Box<dyn std::error::Error>> {
+    let url = format!("{}/addon/{}/files", BASE_URL, addon_id);
     let body = reqwest::get(url).await?.text().await?;
 
-    let file_detail: AddonFileDetail = serde_json::from_str(&body)?;
+    let files: Vec<AddonFileDetail> = serde_json::from_str(&body)?;
 
-    Ok(file_detail)
+    Ok(files)
 }
