@@ -1,10 +1,4 @@
 use serde::{Deserialize, Serialize};
-use std::{fs::File, io::Read, string};
-
-pub mod modloader_type {
-    pub const forge: usize = 1;
-    pub const fabric: usize = 4;
-}
 
 #[allow(non_snake_case)]
 #[derive(Deserialize, Serialize, Debug, Clone)]
@@ -37,13 +31,14 @@ pub struct Addon {
 }
 
 #[allow(non_snake_case)]
-#[derive(Deserialize, Serialize, Debug)]
+#[derive(Deserialize, Serialize, Debug, Clone)]
 pub struct AddonFileDetail {
     pub id: usize,
     pub displayName: String,
     pub fileName: String,
-    pub fileDate: String,
+    pub fileDate: chrono::DateTime<chrono::Utc>,
     pub fileLength: usize,
     pub downloadUrl: String,
     pub isAvailable: bool,
+    pub gameVersion: Vec<String>,
 }
